<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>IsometricGridTop</name>
    <message>
        <location filename="../IsometricGridTop.js" line="+143"/>
        <source>&amp;Top Projection</source>
        <translation type="unfinished">Promítání &amp;zvrchu</translation>
    </message>
</context>
</TS>
